summaryrefslogtreecommitdiff
path: root/protocols/JabberG/jabber_list.h
diff options
context:
space:
mode:
authorGeorge Hazan <george.hazan@gmail.com>2012-07-03 18:15:52 +0000
committerGeorge Hazan <george.hazan@gmail.com>2012-07-03 18:15:52 +0000
commit4641ff7a3a0d6a124c22a5c044bffd04073720fc (patch)
treedd0abb5de957189fc8dd18cd83b3cf97eafe853b /protocols/JabberG/jabber_list.h
parentad4e888349c2d220828c93d2d50635ff23a6fc72 (diff)
shit dropped out
git-svn-id: http://svn.miranda-ng.org/main/trunk@738 1316c22d-e87f-b044-9b9b-93d7a3e3ba9c
Diffstat (limited to 'protocols/JabberG/jabber_list.h')
-rw-r--r--protocols/JabberG/jabber_list.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/protocols/JabberG/jabber_list.h b/protocols/JabberG/jabber_list.h
index c2ee0409e8..503a479ece 100644
--- a/protocols/JabberG/jabber_list.h
+++ b/protocols/JabberG/jabber_list.h
@@ -60,8 +60,9 @@ typedef enum {
ROLE_MODERATOR
} JABBER_GC_ROLE;
-typedef enum { // initial default to RSMODE_SERVER
+typedef enum { // initial default to RSMODE_LASTSEEN
RSMODE_SERVER, // always let server decide ( always send correspondence without resouce name )
+ RSMODE_LASTSEEN, // use the last seen resource ( or let server decide if haven't seen anything yet )
RSMODE_MANUAL // specify resource manually ( see the defaultResource field - must not be NULL )
} JABBER_RESOURCE_MODE;
@@ -113,7 +114,7 @@ struct JABBER_RESOURCE_STATUS
JabberCapsBits jcbManualDiscoveredCaps;
// XEP-0085 gone event support
- BOOL uMessageSessionActive;
+ BOOL bMessageSessionActive;
JABBER_XEP0232_SOFTWARE_INFO* pSoftwareInfo;
};
@@ -128,8 +129,8 @@ struct JABBER_LIST_ITEM
int resourceCount;
JABBER_RESOURCE_STATUS *resource;
JABBER_RESOURCE_STATUS itemResource; // resource for jids without /resource node
- JABBER_RESOURCE_STATUS *lastSeenResource; // index to resource[x] which was last seen active
- JABBER_RESOURCE_STATUS *manualResource; // manually set index to resource[x]
+ int lastSeenResource; // index to resource[x] which was last seen active
+ int manualResource; // manually set index to resource[x]
// int defaultResource; // index to resource[x] which is the default, negative ( -1 ) means no resource is chosen yet
JABBER_RESOURCE_MODE resourceMode;
JABBER_SUBSCRIPTION subscription;
@@ -156,7 +157,7 @@ struct JABBER_LIST_ITEM
HWND hwndGcListAdmin;
HWND hwndGcListOwner;
int iChatState;
- // BOOL bAutoJoin; // chat session was started via auto-join
+ // BOOL bAutoJoin; // chat sessio was started via auto-join
// LIST_FILE
// jid = string representation of port number